@@ -20,7 +20,7 @@ from decimal import Decimal, ROUND_HALF_UP
 from enum import Enum
 from joblib import Parallel
 from numpy.typing import NDArray
-from typing import Any, Final, NamedTuple, Optional, Union
+from typing import Any, Callable, Final, NamedTuple, Optional, Union
 import numpy as np
 import pandas as pd
 import os
@@ -67,10 +67,13 @@ class TrainedModel(NamedTuple):
     Attributes:
         name: Trained model name.
         instance: Trained model instance.
+        predict_fn: :class:`Callable` that overrides calling the model's
+            default ``predict`` function.
     """
 
     name: str
     instance: Any
+    predict_fn: Optional[Callable[[Any, pd.DataFrame], Any]]
 
 
 class ExecSymbol(NamedTuple):
@@ -206,12 +209,12 @@ def to_datetime(
         raise TypeError(f"Unsupported date type: {date_type}")
 
 
-def to_decimal(value: Union[int, float, Decimal, str]) -> Decimal:
+def to_decimal(value: Union[int, float, Decimal]) -> Decimal:
     """Converts ``value`` to :class:`Decimal`."""
     value_type = type(value)
     if value_type == Decimal:
         return value  # type: ignore[return-value]
-    elif value_type == str:
+    elif value_type == int:
         return Decimal(value)
     return Decimal(str(value))
 
