@@ -19,6 +19,7 @@ from .cache import CacheDateFields, IndicatorCacheKey
 from .common import BarData, DataCol, IndicatorSymbol, default_parallel
 from .eval import iqr, relative_entropy
 from .scope import StaticScope
+from .vect import highv, lowv
 from collections import defaultdict
 from dataclasses import asdict
 from joblib import delayed
@@ -303,3 +304,43 @@ class IndicatorsMixin:
                     delayed(fns[ind_name])(**args_fn(ind_name, sym))
                     for ind_name, sym in ind_syms
                 )
+
+
+def highest(name: str, field: str, period: int) -> Indicator:
+    """Creates a rolling high :class:`.Indicator`.
+
+    Args:
+        name: Indicator name.
+        field: :class:`pybroker.common.BarData` field for computing the rolling
+            high.
+        period: Lookback period.
+
+    Returns:
+        Rolling high :class:`.Indicator`.
+    """
+
+    def _highest(data: BarData):
+        values = getattr(data, field)
+        return highv(values, period)
+
+    return indicator(name, _highest)
+
+
+def lowest(name: str, field: str, period: int) -> Indicator:
+    """Creates a rolling low :class:`.Indicator`.
+
+    Args:
+        name: Indicator name.
+        field: :class:`pybroker.common.BarData` field for computing the rolling
+            low.
+        lookback: Lookback period.
+
+    Returns:
+        Rolling low :class:`.Indicator`.
+    """
+
+    def _lowest(data: BarData):
+        values = getattr(data, field)
+        return lowv(values, period)
+
+    return indicator(name, _lowest)
